@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -53,6 +53,7 @@ static GSList  *text_to_string_list( const gchar *text, const gchar *separator,
 #endif
 static gboolean info_dir_is_writable( GFile *file, const gchar *path );
 static gboolean file_is_loadable( GFile *file );
+static void     list_perms( const gchar *path, const gchar *message, const gchar *command );
 
 /**
  * na_core_utils_boolean_from_string
@@ -812,40 +813,6 @@ na_core_utils_selcount_get_ope_int( const gchar *selcount, gchar **ope, gchar **
 	g_free( dup );
 }
 
-/**
- * na_core_utils_dir_list_perms:
- * @path: the path of the directory to be tested.
- * @message: a message to be printed if not %NULL.
- *
- * Displays the permissions of the directory on debug output.
- *
- * Since: 3.1
- */
-void
-na_core_utils_dir_list_perms( const gchar *path, const gchar *message )
-{
-	static const gchar *thisfn = "na_core_utils_dir_list_perms";
-	gchar *cmd;
-	gchar *out, *err;
-	GError *error;
-
-	error = NULL;
-	cmd = g_strdup_printf( "ls -ld %s", path );
-
-	if( !g_spawn_command_line_sync( cmd, &out, &err, NULL, &error )){
-		g_warning( "%s: %s", thisfn, error->message );
-		g_error_free( error );
-
-	} else {
-		g_debug( "%s: dir=%s, message=%s, out=%s", thisfn, path, message, out );
-		g_debug( "%s: dir=%s, message=%s, err=%s", thisfn, path, message, err );
-		g_free( out );
-		g_free( err );
-	}
-
-	g_free( cmd );
-}
-
 /**
  * na_core_utils_dir_is_writable_path:
  * @path: the path of the directory to be tested.
@@ -950,6 +917,21 @@ info_dir_is_writable( GFile *file, const gchar *path_or_uri )
 	return( writable );
 }
 
+/**
+ * na_core_utils_dir_list_perms:
+ * @path: the path of the directory to be tested.
+ * @message: a message to be printed if not %NULL.
+ *
+ * Displays the permissions of the directory on debug output.
+ *
+ * Since: 3.1
+ */
+void
+na_core_utils_dir_list_perms( const gchar *path, const gchar *message )
+{
+	list_perms( path, message, "ls -ld" );
+}
+
 /**
  * na_core_utils_dir_split_ext:
  * @string: the input path or URI to be splitted.
@@ -1132,6 +1114,46 @@ file_is_loadable( GFile *file )
 	return( isok );
 }
 
+/**
+ * na_core_utils_file_list_perms:
+ * @path: the path of the file to be tested.
+ * @message: a message to be printed if not %NULL.
+ *
+ * Displays the permissions of the file on debug output.
+ *
+ * Since: 3.2
+ */
+void
+na_core_utils_file_list_perms( const gchar *path, const gchar *message )
+{
+	list_perms( path, message, "ls -l" );
+}
+
+static void
+list_perms( const gchar *path, const gchar *message, const gchar *command )
+{
+	static const gchar *thisfn = "na_core_utils_list_perms";
+	gchar *cmd;
+	gchar *out, *err;
+	GError *error;
+
+	error = NULL;
+	cmd = g_strdup_printf( "%s %s", command, path );
+
+	if( !g_spawn_command_line_sync( cmd, &out, &err, NULL, &error )){
+		g_warning( "%s: %s", thisfn, error->message );
+		g_error_free( error );
+
+	} else {
+		g_debug( "%s: out=%s", message, out );
+		g_debug( "%s: err=%s", message, err );
+		g_free( out );
+		g_free( err );
+	}
+
+	g_free( cmd );
+}
+
 /**
  * na_core_utils_file_load_from_uri:
  * @uri: the URI the file must be loaded from.
