@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -37,10 +36,11 @@
 #include <string.h>
 
 #include <api/na-core-utils.h>
+#include <api/na-data-boxed.h>
 #include <api/na-data-types.h>
 #include <api/na-iio-provider.h>
 #include <api/na-ifactory-provider.h>
-#include <api/na-data-boxed.h>
+#include <api/na-object-api.h>
 
 #include "na-factory-object.h"
 #include "na-factory-provider.h"
@@ -123,17 +123,14 @@ na_factory_object_define_properties( GObjectClass *class, const NADataGroup *gro
 {
 	static const gchar *thisfn = "na_factory_object_define_properties";
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	g_return_if_fail( G_IS_OBJECT_CLASS( class ));
 
-		g_debug( "%s: class=%p (%s)",
-				thisfn, ( void * ) class, G_OBJECT_CLASS_NAME( class ));
+	g_debug( "%s: class=%p (%s)",
+			thisfn, ( void * ) class, G_OBJECT_CLASS_NAME( class ));
 
-		g_return_if_fail( G_IS_OBJECT_CLASS( class ));
-
-		/* define class properties
-		 */
-		iter_on_data_defs( groups, DATA_DEF_ITER_SET_PROPERTIES, ( NADataDefIterFunc ) define_class_properties_iter, class );
-	}
+	/* define class properties
+	 */
+	iter_on_data_defs( groups, DATA_DEF_ITER_SET_PROPERTIES, ( NADataDefIterFunc ) define_class_properties_iter, class );
 }
 
 static gboolean
@@ -175,23 +172,20 @@ na_factory_object_get_data_def( const NAIFactoryObject *object, const gchar *nam
 
 	def = NULL;
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	NADataGroup *groups = v_get_groups( object );
+	while( groups->group ){
 
-		NADataGroup *groups = v_get_groups( object );
-		while( groups->group ){
+		NADataDef *def = groups->def;
+		if( def ){
+			while( def->name ){
 
-			NADataDef *def = groups->def;
-			if( def ){
-				while( def->name ){
-
-					if( !strcmp( def->name, name )){
-						return( def );
-					}
-					def++;
+				if( !strcmp( def->name, name )){
+					return( def );
 				}
+				def++;
 			}
-			groups++;
 		}
+		groups++;
 	}
 
 	return( def );
@@ -210,12 +204,7 @@ na_factory_object_get_data_groups( const NAIFactoryObject *object )
 
 	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
 
-	groups = NULL;
-
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
-
-		groups = v_get_groups( object );
-	}
+	groups = v_get_groups( object );
 
 	return( groups );
 }
@@ -238,15 +227,12 @@ na_factory_object_iter_on_boxed( const NAIFactoryObject *object, NAFactoryObject
 
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	list = g_object_get_data( G_OBJECT( object ), NA_IFACTORY_OBJECT_PROP_DATA );
+	/*g_debug( "list=%p (count=%u)", ( void * ) list, g_list_length( list ));*/
+	stop = FALSE;
 
-		list = g_object_get_data( G_OBJECT( object ), NA_IFACTORY_OBJECT_PROP_DATA );
-		/*g_debug( "list=%p (count=%u)", ( void * ) list, g_list_length( list ));*/
-		stop = FALSE;
-
-		for( ibox = list ; ibox && !stop ; ibox = ibox->next ){
-			stop = ( *pfn )( object, NA_DATA_BOXED( ibox->data ), user_data );
-		}
+	for( ibox = list ; ibox && !stop ; ibox = ibox->next ){
+		stop = ( *pfn )( object, NA_DATA_BOXED( ibox->data ), user_data );
 	}
 }
 
@@ -269,14 +255,11 @@ na_factory_object_get_default( NAIFactoryObject *object, const gchar *name )
 
 	value = NULL;
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
-		def = na_factory_object_get_data_def( object, name );
-		if( def ){
-			value = g_strdup( def->default_value );
-		}
+	def = na_factory_object_get_data_def( object, name );
+	if( def ){
+		value = g_strdup( def->default_value );
 	}
 
 	return( value );
@@ -297,22 +280,19 @@ na_factory_object_set_defaults( NAIFactoryObject *object )
 
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+	groups = v_get_groups( object );
+	if( !groups ){
+		g_warning( "%s: no NADataGroup found for %s", thisfn, G_OBJECT_TYPE_NAME( object ));
 
-		groups = v_get_groups( object );
-		if( !groups ){
-			g_warning( "%s: no NADataGroup found for %s", thisfn, G_OBJECT_TYPE_NAME( object ));
+	} else {
+		iter_data = g_new0( NafoDefaultIter, 1 );
+		iter_data->object = object;
 
-		} else {
-			iter_data = g_new0( NafoDefaultIter, 1 );
-			iter_data->object = object;
+		iter_on_data_defs( groups, DATA_DEF_ITER_SET_DEFAULTS, ( NADataDefIterFunc ) set_defaults_iter, iter_data );
 
-			iter_on_data_defs( groups, DATA_DEF_ITER_SET_DEFAULTS, ( NADataDefIterFunc ) set_defaults_iter, iter_data );
-
-			g_free( iter_data );
-		}
+		g_free( iter_data );
 	}
 }
 
@@ -352,20 +332,17 @@ na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( target ));
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( source ));
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	GList *src_list = g_object_get_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA );
 
-		GList *src_list = g_object_get_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA );
+	if( g_list_find( src_list, boxed )){
+		src_list = g_list_remove( src_list, boxed );
+		g_object_set_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA, src_list );
 
-		if( g_list_find( src_list, boxed )){
-			src_list = g_list_remove( src_list, boxed );
-			g_object_set_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA, src_list );
+		attach_boxed_to_object( target, boxed );
 
-			attach_boxed_to_object( target, boxed );
-
-			const NADataDef *src_def = na_data_boxed_get_data_def( boxed );
-			NADataDef *tgt_def = na_factory_object_get_data_def( target, src_def->name );
-			na_data_boxed_set_data_def( boxed, tgt_def );
-		}
+		const NADataDef *src_def = na_data_boxed_get_data_def( boxed );
+		NADataDef *tgt_def = na_factory_object_get_data_def( target, src_def->name );
+		na_data_boxed_set_data_def( boxed, tgt_def );
 	}
 }
 
@@ -375,12 +352,17 @@ na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *
  * @source: the source #NAIFactoryObject instance.
  *
  * Copies one instance to another.
+ * Takes care of not overriding provider data.
  */
 void
 na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source )
 {
 	static const gchar *thisfn = "na_factory_object_copy";
+	GList *dest_list, *idest, *inext;
 	GList *src_list, *isrc;
+	NADataBoxed *boxed;
+	const NADataDef *def;
+	void *provider, *provider_data;
 
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( target ));
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( source ));
@@ -390,20 +372,44 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
 			( void * ) target, G_OBJECT_TYPE_NAME( target ),
 			( void * ) source, G_OBJECT_TYPE_NAME( source ));
 
+	/* first remove copyable data from target
+	 */
+	provider = na_object_get_provider( target );
+	provider_data = na_object_get_provider_data( target );
+
+	idest = dest_list = g_object_get_data( G_OBJECT( target ), NA_IFACTORY_OBJECT_PROP_DATA );
+	while( idest ){
+		boxed = NA_DATA_BOXED( idest->data );
+		inext = idest->next;
+		def = na_data_boxed_get_data_def( boxed );
+		if( def->copyable ){
+			dest_list = g_list_remove_link( dest_list, idest );
+			g_object_unref( idest->data );
+		}
+		idest = inext;
+	}
+	g_object_set_data( G_OBJECT( target ), NA_IFACTORY_OBJECT_PROP_DATA, dest_list );
+
+	/* only then copy copyable data from source
+	 */
 	src_list = g_object_get_data( G_OBJECT( source ), NA_IFACTORY_OBJECT_PROP_DATA );
-
 	for( isrc = src_list ; isrc ; isrc = isrc->next ){
-
-		NADataBoxed *src_boxed = NA_DATA_BOXED( isrc->data );
-		const NADataDef *def = na_data_boxed_get_data_def( src_boxed );
-
+		boxed = NA_DATA_BOXED( isrc->data );
+		def = na_data_boxed_get_data_def( boxed );
 		if( def->copyable ){
 			NADataBoxed *tgt_boxed = na_ifactory_object_get_data_boxed( target, def->name );
 			if( !tgt_boxed ){
 				tgt_boxed = na_data_boxed_new( def );
 				attach_boxed_to_object( target, tgt_boxed );
 			}
-			na_boxed_set_from_boxed( NA_BOXED( tgt_boxed ), NA_BOXED( src_boxed ));
+			na_boxed_set_from_boxed( NA_BOXED( tgt_boxed ), NA_BOXED( boxed ));
+		}
+	}
+
+	if( provider ){
+		na_object_set_provider( target, provider );
+		if( provider_data ){
+			na_object_set_provider_data( target, provider_data );
 		}
 	}
 
@@ -597,29 +603,26 @@ na_factory_object_read_item( NAIFactoryObject *object, const NAIFactoryProvider
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 	g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
 
-	if( ifactory_object_initialized && !ifactory_object_finalized ){
+	NADataGroup *groups = v_get_groups( object );
 
-		NADataGroup *groups = v_get_groups( object );
+	if( groups ){
+		v_read_start( object, reader, reader_data, messages );
 
-		if( groups ){
-			v_read_start( object, reader, reader_data, messages );
+		NafoReadIter *iter = g_new0( NafoReadIter, 1 );
+		iter->object = object;
+		iter->reader = ( NAIFactoryProvider * ) reader;
+		iter->reader_data = reader_data;
+		iter->messages = messages;
 
-			NafoReadIter *iter = g_new0( NafoReadIter, 1 );
-			iter->object = object;
-			iter->reader = ( NAIFactoryProvider * ) reader;
-			iter->reader_data = reader_data;
-			iter->messages = messages;
+		iter_on_data_defs( groups, DATA_DEF_ITER_READ_ITEM, ( NADataDefIterFunc ) read_data_iter, iter );
 
-			iter_on_data_defs( groups, DATA_DEF_ITER_READ_ITEM, ( NADataDefIterFunc ) read_data_iter, iter );
+		g_free( iter );
 
-			g_free( iter );
+		v_read_done( object, reader, reader_data, messages );
 
-			v_read_done( object, reader, reader_data, messages );
-
-		} else {
-			g_warning( "%s: class %s doesn't return any NADataGroup structure",
-					thisfn, G_OBJECT_TYPE_NAME( object ));
-		}
+	} else {
+		g_warning( "%s: class %s doesn't return any NADataGroup structure",
+				thisfn, G_OBJECT_TYPE_NAME( object ));
 	}
 }
 
@@ -751,10 +754,10 @@ na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *nam
  *
  * Returns: the searched value.
  *
- * If the type of the value is NA_DATA_TYPE_STRING, NA_DATA_TYPE_LOCALE_STRING,
- * or NA_DATA_TYPE_STRING_LIST, then the returned value is a newly allocated
- * one and should be g_free() (resp. na_core_utils_slist_free()) by the
- * caller.
+ * If the type of the value is NA_DATA_TYPE_STRING or NA_DATA_TYPE_LOCALE_STRING
+ * (resp. NA_DATA_TYPE_STRING_LIST), then the returned value is a newly allocated
+ * string (resp. GSList) and should be g_free() (resp. na_core_utils_slist_free())
+ * by the caller.
  */
 void *
 na_factory_object_get_as_void( const NAIFactoryObject *object, const gchar *name )
@@ -774,6 +777,25 @@ na_factory_object_get_as_void( const NAIFactoryObject *object, const gchar *name
 	return( value );
 }
 
+/*
+ * na_factory_object_is_set:
+ * @object: this #NAIFactoryObject instance.
+ * @name: the elementary data whose value is to be tested.
+ *
+ * Returns: %TRUE if the value is set (may be %NULL), %FALSE else.
+ */
+gboolean
+na_factory_object_is_set( const NAIFactoryObject *object, const gchar *name )
+{
+	NADataBoxed *boxed;
+
+	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), FALSE );
+
+	boxed = na_ifactory_object_get_data_boxed( object, name );
+
+	return( boxed != NULL );
+}
+
 /*
  * na_factory_object_set_from_value:
  * @object: this #NAIFactoryObject instance.
@@ -829,7 +851,7 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
 	} else {
 		NADataDef *def = na_factory_object_get_data_def( object, name );
 		if( !def ){
-			g_warning( "%s: unknown NADataDef %s", thisfn, name );
+			g_warning( "%s: unknown NADataDef %s for %s", thisfn, name, G_OBJECT_TYPE_NAME( object ));
 
 		} else {
 			boxed = na_data_boxed_new( def );
