@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -31,6 +31,7 @@
 #include <config.h>
 #endif
 
+#include <glib.h>
 #include <string.h>
 
 #include "na-gtk-utils.h"
@@ -158,25 +159,32 @@ na_gtk_utils_restore_window_position( GtkWindow *toplevel, const gchar *wsp_name
 	width = MAX( 1, width );
 	height = MAX( 1, height );
 
-	display = gdk_display_get_default();
-	screen = gdk_display_get_screen( display, 0 );
-	screen_width = gdk_screen_get_width( screen );
-	screen_height = gdk_screen_get_height( screen );
-
-	/* very dirty hack based on the assumption that Gnome 2.x has a bottom
-	 * and a top panel bars, while Gnome 3.x only has one.
-	 * Don't know how to get usable height of screen, and don't bother today.
+	/* bad hack for the first time we open the main window
+	 * try to target an ideal size and position
 	 */
-	screen_height -= DEFAULT_HEIGHT;
-#if ! GTK_CHECK_VERSION( 3, 0, 0 )
-	screen_height -= DEFAULT_HEIGHT;
-#endif
+	if( !strcmp( wsp_name, NA_IPREFS_MAIN_WINDOW_WSP )){
+		if( x == 1 && y == 1 && width == 1 && height == 1 ){
+			x = 50;
+			y = 70;
+			width = 1030;
+			height = 560;
 
-	width = MIN( width, screen_width-x );
-	height = MIN( height, screen_height-y );
+		} else {
+			display = gdk_display_get_default();
+			screen = gdk_display_get_screen( display, 0 );
+			screen_width = gdk_screen_get_width( screen );
+			screen_height = gdk_screen_get_height( screen );
+			g_debug( "%s: screen=(%d,%d), DEFAULT_HEIGHT=%d",
+					thisfn, screen_width, screen_height, DEFAULT_HEIGHT );
 
-	g_debug( "%s: wsp_name=%s, screen=(%d,%d), x=%d, y=%d, width=%d, height=%d",
-			thisfn, wsp_name, screen_width, screen_height, x, y, width, height );
+			screen_height -= 2*DEFAULT_HEIGHT;
+			width = MIN( width, screen_width-x );
+			height = MIN( height, screen_height-y );
+		}
+	}
+
+	g_debug( "%s: wsp_name=%s, x=%d, y=%d, width=%d, height=%d",
+			thisfn, wsp_name, x, y, width, height );
 
 	gtk_window_move( toplevel, x, y );
 	gtk_window_resize( toplevel, width, height );
