@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -38,9 +37,17 @@
 #include <api/na-data-def.h>
 #include <api/na-data-types.h>
 
+/*
+ * As of 3.2 non copyables data are:
+ * - the type
+ * - non localized icon name
+ * - subitems pointers list and string list
+ * - read-only status
+ */
+
 NADataDef data_def_item [] = {
 
-	/* this data is marked as non readable as it has to be readen specifically
+	/* this data is marked as non readable as it has to be read specifically
 	 * in order to be able to create the corresponding NAObjectItem-derived
 	 * object
 	 * it is not writable as different I/O providers may have different values
@@ -60,7 +67,7 @@ NADataDef data_def_item [] = {
 					"- 'Action',\n" \
 					"- 'Menu'.\n" \
 					"The value is case sensitive and must not be localized." ),
-				NAFD_TYPE_STRING,
+				NA_DATA_TYPE_STRING,
 				NULL,
 				FALSE,
 				FALSE,
@@ -88,8 +95,8 @@ NADataDef data_def_item [] = {
 				N_( "The label of the menu item that will appear in the file manager context " \
 					"menu when the selection matches the appearance condition settings.\n" \
 					"It is also used as a default for the toolbar label of an action." ),
-				NAFD_TYPE_LOCALE_STRING,
-				"",
+				NA_DATA_TYPE_LOCALE_STRING,
+				N_( "Empty label" ),
 				FALSE,
 				TRUE,
 				TRUE,
@@ -112,7 +119,7 @@ NADataDef data_def_item [] = {
 				N_( "The tooltip of the menu item that will appear in the file manager " \
 					"statusbar when the user points to the file manager context menu item " \
 					"with his/her mouse." ),
-				NAFD_TYPE_LOCALE_STRING,
+				NA_DATA_TYPE_LOCALE_STRING,
 				"",
 				FALSE,
 				TRUE,
@@ -137,7 +144,7 @@ NADataDef data_def_item [] = {
 					"in the file manager context menu when the selection matches the appearance " \
 					"conditions settings.\n" \
 					"May be the localized name of a themed icon, or a full path to any appropriate image." ),
-				NAFD_TYPE_LOCALE_STRING,
+				NA_DATA_TYPE_LOCALE_STRING,
 				"",
 				FALSE,
 				TRUE,
@@ -161,7 +168,7 @@ NADataDef data_def_item [] = {
 				FALSE,
 				"Unlocalized icon name or path",
 				NULL,
-				NAFD_TYPE_STRING,
+				NA_DATA_TYPE_STRING,
 				"",
 				FALSE,
 				FALSE,
@@ -184,7 +191,7 @@ NADataDef data_def_item [] = {
 				N_( "Description relative to the item" ),
 				N_( "Some text which explains the goal of the menu or the action.\n" \
 					"May be used, e.g. when displaying available items on a web site." ),
-				NAFD_TYPE_LOCALE_STRING,
+				NA_DATA_TYPE_LOCALE_STRING,
 				"",
 				FALSE,
 				TRUE,
@@ -211,7 +218,7 @@ NADataDef data_def_item [] = {
 					"an already existing shortcut to define this one.\n" \
 					"The format may look like \"<Control>a\" or \"<Shift><Alt>F1\".\n" \
 					"Defaults to empty." ),
-				NAFD_TYPE_STRING,
+				NA_DATA_TYPE_STRING,
 				"",
 				FALSE,
 				TRUE,
@@ -235,7 +242,7 @@ NADataDef data_def_item [] = {
 				TRUE,
 				"Subitems",
 				"List of subitems objects",
-				NAFD_TYPE_POINTER,
+				NA_DATA_TYPE_POINTER,
 				NULL,
 				FALSE,
 				FALSE,			/* not copyable */
@@ -263,7 +270,7 @@ NADataDef data_def_item [] = {
 					"if the item is a menu, or profiles if the item is an action.\n" \
 					"If this list doesn't exist or is empty for an action or a menu, " \
 					"subitems are attached in the order of the read operations." ),
-				NAFD_TYPE_STRING_LIST,
+				NA_DATA_TYPE_STRING_LIST,
 				NULL,
 				FALSE,
 				FALSE,
@@ -283,11 +290,11 @@ NADataDef data_def_item [] = {
 				TRUE,
 				TRUE,
 				TRUE,
-				N_( "Whether the action or the menu is enabled (default)" ),
+				N_( "Whether the action or the menu is enabled" ),
 				N_( "If the or the menu action is disabled, it will never appear in the " \
 					"file manager context menu.\n" \
 					"Defaults to TRUE." ),
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"true",
 				FALSE,
 				TRUE,
@@ -300,7 +307,7 @@ NADataDef data_def_item [] = {
 				"enabled",
 				0,
 				G_OPTION_ARG_NONE,
-				NULL,
+				N_( "Whether the action or the menu is enabled [enabled]" ),
 				NULL },
 
 	/* dynamic data, so non readable / non writable
@@ -317,10 +324,10 @@ NADataDef data_def_item [] = {
 				"as this also depend of parameters set by user and administrator. " \
 				"Also, a property initially set to FALSE when first unserializing may be set to" \
 				"TRUE if an eccor occurs on a later write operation.",
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"false",
 				FALSE,
-				TRUE,
+				FALSE,
 				FALSE,
 				FALSE,
 				FALSE,
@@ -341,7 +348,7 @@ NADataDef data_def_item [] = {
 				TRUE,
 				"I/O provider",
 				"A pointer to the NAIOProvider object.",
-				NAFD_TYPE_POINTER,
+				NA_DATA_TYPE_POINTER,
 				NULL,
 				FALSE,
 				TRUE,
@@ -368,7 +375,7 @@ NADataDef data_def_item [] = {
 				TRUE,
 				"I/O provider data",
 				"A pointer to some NAIOProvider specific data.",
-				NAFD_TYPE_POINTER,
+				NA_DATA_TYPE_POINTER,
 				NULL,
 				FALSE,
 				FALSE,
@@ -401,7 +408,7 @@ NADataDef data_def_item [] = {
 				TRUE,
 				N_( "Version of the format" ),
 				N_( "The version of the configuration format that will be used to manage backward compatibility." ),
-				NAFD_TYPE_UINT,
+				NA_DATA_TYPE_UINT,
 				"3",
 				FALSE,
 				TRUE,
