@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -42,38 +41,40 @@
  */
 
 #include <api/na-object-item.h>
+#include <api/na-timeout.h>
 
 #include "nadp-desktop-file.h"
 
 G_BEGIN_DECLS
 
-#define NADP_DESKTOP_PROVIDER_TYPE					( nadp_desktop_provider_get_type())
-#define NADP_DESKTOP_PROVIDER( object )				( G_TYPE_CHECK_INSTANCE_CAST( object, NADP_DESKTOP_PROVIDER_TYPE, NadpDesktopProvider ))
-#define NADP_DESKTOP_PROVIDER_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NADP_DESKTOP_PROVIDER_TYPE, NadpDesktopProviderClass ))
-#define NADP_IS_DESKTOP_PROVIDER( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NADP_DESKTOP_PROVIDER_TYPE ))
-#define NADP_IS_DESKTOP_PROVIDER_CLASS( klass )		( G_TYPE_CHECK_CLASS_TYPE(( klass ), NADP_DESKTOP_PROVIDER_TYPE ))
-#define NADP_DESKTOP_PROVIDER_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NADP_DESKTOP_PROVIDER_TYPE, NadpDesktopProviderClass ))
-
-typedef struct NadpDesktopProviderPrivate      NadpDesktopProviderPrivate;
+#define NADP_TYPE_DESKTOP_PROVIDER                ( nadp_desktop_provider_get_type())
+#define NADP_DESKTOP_PROVIDER( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NADP_TYPE_DESKTOP_PROVIDER, NadpDesktopProvider ))
+#define NADP_DESKTOP_PROVIDER_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NADP_TYPE_DESKTOP_PROVIDER, NadpDesktopProviderClass ))
+#define NADP_IS_DESKTOP_PROVIDER( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NADP_TYPE_DESKTOP_PROVIDER ))
+#define NADP_IS_DESKTOP_PROVIDER_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NADP_TYPE_DESKTOP_PROVIDER ))
+#define NADP_DESKTOP_PROVIDER_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NADP_TYPE_DESKTOP_PROVIDER, NadpDesktopProviderClass ))
 
 /* private instance data
  */
-struct NadpDesktopProviderPrivate {
-	gboolean dispose_has_run;
-	GList   *monitors;
-	GTimeVal last_event;
-	guint    event_source_id;
-};
+typedef struct _NadpDesktopProviderPrivate {
+	/*< private >*/
+	gboolean  dispose_has_run;
+	GList    *monitors;
+	NATimeout timeout;
+}
+	NadpDesktopProviderPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObject                     parent;
 	NadpDesktopProviderPrivate *private;
 }
 	NadpDesktopProvider;
 
-typedef struct NadpDesktopProviderClassPrivate NadpDesktopProviderClassPrivate;
+typedef struct _NadpDesktopProviderClassPrivate   NadpDesktopProviderClassPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObjectClass                     parent;
 	NadpDesktopProviderClassPrivate *private;
 }
