@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -38,17 +37,19 @@
 
 #include <api/na-core-utils.h>
 
+#include <core/na-settings.h>
+
 #include "nact-add-capability-dialog.h"
 
 /* private class data
  */
-struct NactAddCapabilityDialogClassPrivate {
+struct _NactAddCapabilityDialogClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NactAddCapabilityDialogPrivate {
+struct _NactAddCapabilityDialogPrivate {
 	gboolean dispose_has_run;
 	GSList  *already_used;
 	gchar   *capability;
@@ -78,22 +79,22 @@ static CapabilityTextStruct st_caps[] = {
 		{ NULL },
 };
 
-static GObjectClass *st_parent_class = NULL;
+static const gchar  *st_xmlui_filename = PKGUIDIR "/nact-add-capability.ui";
+static const gchar  *st_toplevel_name  = "AddCapabilityDialog";
+static const gchar  *st_wsp_name       = NA_IPREFS_CAPABILITY_ADD_CAPABILITY_WSP;
+
+static GObjectClass *st_parent_class   = NULL;
 
 static GType    register_type( void );
 static void     class_init( NactAddCapabilityDialogClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
+static void     instance_constructed( GObject *dialog );
 static void     instance_dispose( GObject *dialog );
 static void     instance_finalize( GObject *dialog );
 
-static NactAddCapabilityDialog *add_capability_dialog_new( BaseWindow *parent );
-
-static gchar   *base_get_iprefs_window_id( const BaseWindow *window );
-static gchar   *base_get_dialog_name( const BaseWindow *window );
-static gchar   *base_get_ui_filename( const BaseWindow *dialog );
-static void     on_base_initial_load_dialog( NactAddCapabilityDialog *editor, gpointer user_data );
-static void     on_base_runtime_init_dialog( NactAddCapabilityDialog *editor, gpointer user_data );
-static void     on_base_all_widgets_showed( NactAddCapabilityDialog *editor, gpointer user_data );
+static void     on_base_initialize_gtk( NactAddCapabilityDialog *editor, GtkDialog *toplevel, gpointer user_data );
+static void     on_base_initialize_window( NactAddCapabilityDialog *editor, gpointer user_data );
+static void     on_base_show_widgets( NactAddCapabilityDialog *editor, gpointer user_data );
 static gboolean on_button_press_event( GtkWidget *widget, GdkEventButton *event, NactAddCapabilityDialog *editor );
 static void     on_cancel_clicked( GtkButton *button, NactAddCapabilityDialog *editor );
 static void     on_ok_clicked( GtkButton *button, NactAddCapabilityDialog *editor );
@@ -104,8 +105,7 @@ static void     display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell,
 static gboolean setup_values_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter* iter, GSList *capabilities );
 static void     try_for_send_ok( NactAddCapabilityDialog *dialog );
 static void     send_ok( NactAddCapabilityDialog *dialog );
-static void     validate_dialog( NactAddCapabilityDialog *editor );
-static gboolean base_dialog_response( GtkDialog *dialog, gint code, BaseWindow *window );
+static void     on_dialog_ok( BaseDialog *dialog );
 
 GType
 nact_add_capability_dialog_get_type( void )
@@ -139,7 +139,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( BASE_DIALOG_TYPE, "NactAddCapabilityDialog", &info, 0 );
+	type = g_type_register_static( BASE_TYPE_DIALOG, "NactAddCapabilityDialog", &info, 0 );
 
 	return( type );
 }
@@ -149,23 +149,21 @@ class_init( NactAddCapabilityDialogClass *klass )
 {
 	static const gchar *thisfn = "nact_add_capability_dialog_class_init";
 	GObjectClass *object_class;
-	BaseWindowClass *base_class;
+	BaseDialogClass *dialog_class;
 
 	g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 	st_parent_class = g_type_class_peek_parent( klass );
 
 	object_class = G_OBJECT_CLASS( klass );
+	object_class->constructed = instance_constructed;
 	object_class->dispose = instance_dispose;
 	object_class->finalize = instance_finalize;
 
 	klass->private = g_new0( NactAddCapabilityDialogClassPrivate, 1 );
 
-	base_class = BASE_WINDOW_CLASS( klass );
-	base_class->dialog_response = base_dialog_response;
-	base_class->get_toplevel_name = base_get_dialog_name;
-	base_class->get_iprefs_window_id = base_get_iprefs_window_id;
-	base_class->get_ui_filename = base_get_ui_filename;
+	dialog_class = BASE_DIALOG_CLASS( klass );
+	dialog_class->ok = on_dialog_ok;
 }
 
 static void
@@ -175,33 +173,56 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	NactAddCapabilityDialog *self;
 
 	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( instance ));
+
 	g_debug( "%s: instance=%p, klass=%p", thisfn, ( void * ) instance, ( void * ) klass );
+
 	self = NACT_ADD_CAPABILITY_DIALOG( instance );
 
 	self->private = g_new0( NactAddCapabilityDialogPrivate, 1 );
 
-	base_window_signal_connect(
-			BASE_WINDOW( instance ),
-			G_OBJECT( instance ),
-			BASE_WINDOW_SIGNAL_INITIAL_LOAD,
-			G_CALLBACK( on_base_initial_load_dialog ));
-
-	base_window_signal_connect(
-			BASE_WINDOW( instance ),
-			G_OBJECT( instance ),
-			BASE_WINDOW_SIGNAL_RUNTIME_INIT,
-			G_CALLBACK( on_base_runtime_init_dialog ));
-
-	base_window_signal_connect(
-			BASE_WINDOW( instance ),
-			G_OBJECT( instance ),
-			BASE_WINDOW_SIGNAL_ALL_WIDGETS_SHOWED,
-			G_CALLBACK( on_base_all_widgets_showed));
-
 	self->private->dispose_has_run = FALSE;
 	self->private->capability = NULL;
 }
 
+static void
+instance_constructed( GObject *dialog )
+{
+	static const gchar *thisfn = "nact_add_capability_dialog_instance_constructed";
+	NactAddCapabilityDialogPrivate *priv;
+
+	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( dialog ));
+
+	priv = NACT_ADD_CAPABILITY_DIALOG( dialog )->private;
+
+	if( !priv->dispose_has_run ){
+
+		/* chain up to the parent class */
+		if( G_OBJECT_CLASS( st_parent_class )->constructed ){
+			G_OBJECT_CLASS( st_parent_class )->constructed( dialog );
+		}
+
+		g_debug( "%s: dialog=%p (%s)", thisfn, ( void * ) dialog, G_OBJECT_TYPE_NAME( dialog ));
+
+		base_window_signal_connect(
+				BASE_WINDOW( dialog ),
+				G_OBJECT( dialog ),
+				BASE_SIGNAL_INITIALIZE_GTK,
+				G_CALLBACK( on_base_initialize_gtk ));
+
+		base_window_signal_connect(
+				BASE_WINDOW( dialog ),
+				G_OBJECT( dialog ),
+				BASE_SIGNAL_INITIALIZE_WINDOW,
+				G_CALLBACK( on_base_initialize_window ));
+
+		base_window_signal_connect(
+				BASE_WINDOW( dialog ),
+				G_OBJECT( dialog ),
+				BASE_SIGNAL_SHOW_WIDGETS,
+				G_CALLBACK( on_base_show_widgets ));
+	}
+}
+
 static void
 instance_dispose( GObject *dialog )
 {
@@ -212,10 +233,11 @@ instance_dispose( GObject *dialog )
 	GtkTreeSelection *selection;
 
 	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( dialog ));
-	g_debug( "%s: dialog=%p", thisfn, ( void * ) dialog );
+
 	self = NACT_ADD_CAPABILITY_DIALOG( dialog );
 
 	if( !self->private->dispose_has_run ){
+		g_debug( "%s: dialog=%p (%s)", thisfn, ( void * ) dialog, G_OBJECT_TYPE_NAME( dialog ));
 
 		self->private->dispose_has_run = TRUE;
 
@@ -239,7 +261,9 @@ instance_finalize( GObject *dialog )
 	NactAddCapabilityDialog *self;
 
 	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( dialog ));
-	g_debug( "%s: dialog=%p", thisfn, ( void * ) dialog );
+
+	g_debug( "%s: dialog=%p (%s)", thisfn, ( void * ) dialog, G_OBJECT_TYPE_NAME( dialog ));
+
 	self = NACT_ADD_CAPABILITY_DIALOG( dialog );
 
 	na_core_utils_slist_free( self->private->already_used );
@@ -253,18 +277,6 @@ instance_finalize( GObject *dialog )
 	}
 }
 
-/*
- * Returns a newly allocated NactAddCapabilityDialog object.
- *
- * @parent: the BaseWindow parent of this dialog (usually, the main
- * toplevel window of the application).
- */
-static NactAddCapabilityDialog *
-add_capability_dialog_new( BaseWindow *parent )
-{
-	return( g_object_new( NACT_ADD_CAPABILITY_DIALOG_TYPE, BASE_WINDOW_PROP_PARENT, parent, NULL ));
-}
-
 /**
  * nact_add_capability_dialog_run:
  * @parent: the BaseWindow parent of this dialog
@@ -287,40 +299,29 @@ nact_add_capability_dialog_run( BaseWindow *parent, GSList *capabilities )
 
 	g_return_val_if_fail( BASE_IS_WINDOW( parent ), NULL );
 
-	dialog = add_capability_dialog_new( parent );
+	dialog = g_object_new( NACT_TYPE_ADD_CAPABILITY_DIALOG,
+					BASE_PROP_PARENT,         parent,
+					BASE_PROP_XMLUI_FILENAME, st_xmlui_filename,
+					BASE_PROP_TOPLEVEL_NAME,  st_toplevel_name,
+					BASE_PROP_WSP_NAME,       st_wsp_name,
+					NULL );
+
 	dialog->private->already_used = na_core_utils_slist_duplicate( capabilities );
+	capability = NULL;
 
-	base_window_run( BASE_WINDOW( dialog ));
-
-	capability = g_strdup( dialog->private->capability );
+	if( base_window_run( BASE_WINDOW( dialog )) == GTK_RESPONSE_OK ){
+		capability = g_strdup( dialog->private->capability );
+	}
 
 	g_object_unref( dialog );
 
 	return( capability );
 }
 
-static gchar *
-base_get_iprefs_window_id( const BaseWindow *window )
-{
-	return( g_strdup( "add-capability-dialog" ));
-}
-
-static gchar *
-base_get_dialog_name( const BaseWindow *window )
-{
-	return( g_strdup( "AddCapabilityDialog" ));
-}
-
-static gchar *
-base_get_ui_filename( const BaseWindow *dialog )
-{
-	return( g_strdup( PKGDATADIR "/nact-add-capability.ui" ));
-}
-
 static void
-on_base_initial_load_dialog( NactAddCapabilityDialog *dialog, gpointer user_data )
+on_base_initialize_gtk( NactAddCapabilityDialog *dialog, GtkDialog *toplevel, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_add_capability_dialog_on_initial_load_dialog";
+	static const gchar *thisfn = "nact_add_capability_dialog_on_base_initialize_gtk";
 	GtkTreeView *listview;
 	GtkTreeModel *model;
 	GtkTreeViewColumn *column;
@@ -330,7 +331,9 @@ on_base_initial_load_dialog( NactAddCapabilityDialog *dialog, gpointer user_data
 	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( dialog ));
 
 	if( !dialog->private->dispose_has_run ){
-		g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
+
+		g_debug( "%s: dialog=%p, toplevel=%p, user_data=%p",
+				thisfn, ( void * ) dialog, ( void * ) toplevel, ( void * ) user_data );
 
 		listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( dialog ), "CapabilitiesTreeView" ));
 
@@ -363,13 +366,17 @@ on_base_initial_load_dialog( NactAddCapabilityDialog *dialog, gpointer user_data
 
 		selection = gtk_tree_view_get_selection( listview );
 		gtk_tree_selection_set_mode( selection, GTK_SELECTION_BROWSE );
+
+#if !GTK_CHECK_VERSION( 2,22,0 )
+		gtk_dialog_set_has_separator( toplevel, FALSE );
+#endif
 	}
 }
 
 static void
-on_base_runtime_init_dialog( NactAddCapabilityDialog *dialog, gpointer user_data )
+on_base_initialize_window( NactAddCapabilityDialog *dialog, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_add_capability_dialog_on_runtime_init_dialog";
+	static const gchar *thisfn = "nact_add_capability_dialog_on_base_initialize_window";
 	GtkTreeView *listview;
 	GtkListStore *model;
 	GtkTreeIter row;
@@ -378,6 +385,7 @@ on_base_runtime_init_dialog( NactAddCapabilityDialog *dialog, gpointer user_data
 	g_return_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( dialog ));
 
 	if( !dialog->private->dispose_has_run ){
+
 		g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
 
 		listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( dialog ), "CapabilitiesTreeView" ));
@@ -395,36 +403,24 @@ on_base_runtime_init_dialog( NactAddCapabilityDialog *dialog, gpointer user_data
 		gtk_tree_model_foreach( GTK_TREE_MODEL( model ), ( GtkTreeModelForeachFunc ) setup_values_iter, dialog->private->already_used );
 
 		/* catch double-click */
-		base_window_signal_connect(
-				BASE_WINDOW( dialog ),
-				G_OBJECT( listview ),
-				"button-press-event",
-				G_CALLBACK( on_button_press_event ));
+		base_window_signal_connect( BASE_WINDOW( dialog ),
+				G_OBJECT( listview ), "button-press-event", G_CALLBACK( on_button_press_event ));
 
-		base_window_signal_connect(
-				BASE_WINDOW( dialog ),
-				G_OBJECT( gtk_tree_view_get_selection( listview )),
-				"changed",
-				G_CALLBACK( on_selection_changed ));
+		base_window_signal_connect( BASE_WINDOW( dialog ),
+				G_OBJECT( gtk_tree_view_get_selection( listview )), "changed", G_CALLBACK( on_selection_changed ));
 
-		base_window_signal_connect_by_name(
-				BASE_WINDOW( dialog ),
-				"CancelButton",
-				"clicked",
-				G_CALLBACK( on_cancel_clicked ));
+		base_window_signal_connect_by_name( BASE_WINDOW( dialog ),
+				"CancelButton", "clicked", G_CALLBACK( on_cancel_clicked ));
 
-		base_window_signal_connect_by_name(
-				BASE_WINDOW( dialog ),
-				"OKButton",
-				"clicked",
-				G_CALLBACK( on_ok_clicked ));
+		base_window_signal_connect_by_name( BASE_WINDOW( dialog ),
+				"OKButton", "clicked", G_CALLBACK( on_ok_clicked ));
 	}
 }
 
 static void
-on_base_all_widgets_showed( NactAddCapabilityDialog *dialog, gpointer user_data )
+on_base_show_widgets( NactAddCapabilityDialog *dialog, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_add_capability_dialog_on_all_widgets_showed";
+	static const gchar *thisfn = "nact_add_capability_dialog_on_base_show_widgets";
 	GtkTreeView *listview;
 	GtkTreePath *path;
 	GtkTreeSelection *selection;
@@ -460,7 +456,7 @@ on_button_press_event( GtkWidget *widget, GdkEventButton *event, NactAddCapabili
 static void
 on_cancel_clicked( GtkButton *button, NactAddCapabilityDialog *dialog )
 {
-	GtkWindow *toplevel = base_window_get_toplevel( BASE_WINDOW( dialog ));
+	GtkWindow *toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( dialog ));
 
 	gtk_dialog_response( GTK_DIALOG( toplevel ), GTK_RESPONSE_CLOSE );
 }
@@ -548,16 +544,7 @@ try_for_send_ok( NactAddCapabilityDialog *dialog )
 
 	button = base_window_get_widget( BASE_WINDOW( dialog ), "OKButton" );
 
-/* gtk_widget_is_sensitive() appears with Gtk+ 2.17.5 released on 2009-07-18
- * see http://git.gnome.org/browse/gtk+/commit/?id=8f6017622937770082f7b49dfbe135fae5608704
- * GTK_WIDGET_IS_SENSITIVE macro is deprecated since 2.19.7 released on 2010-03-09
- * see http://git.gnome.org/browse/gtk+/commit/?id=a27d5a2c9eba7af5b056de32ff9b2b4dd1eb97e1
- */
-#if GTK_CHECK_VERSION( 2, 17, 5 )
 	is_sensitive = gtk_widget_is_sensitive( button );
-#else
-	is_sensitive = GTK_WIDGET_IS_SENSITIVE( button );
-#endif
 
 	if( is_sensitive ){
 		send_ok( dialog );
@@ -567,14 +554,15 @@ try_for_send_ok( NactAddCapabilityDialog *dialog )
 static void
 send_ok( NactAddCapabilityDialog *dialog )
 {
-	GtkWindow *toplevel = base_window_get_toplevel( BASE_WINDOW( dialog ));
+	GtkWindow *toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( dialog ));
 
 	gtk_dialog_response( GTK_DIALOG( toplevel ), GTK_RESPONSE_OK );
 }
 
 static void
-validate_dialog( NactAddCapabilityDialog *dialog )
+on_dialog_ok( BaseDialog *dialog )
 {
+	NactAddCapabilityDialog *editor;
 	GtkTreeView *listview;
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -582,42 +570,15 @@ validate_dialog( NactAddCapabilityDialog *dialog )
 	GtkTreePath *path;
 	GtkTreeIter iter;
 
-	listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( dialog ), "CapabilitiesTreeView" ));
+	editor = NACT_ADD_CAPABILITY_DIALOG( dialog );
+
+	listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "CapabilitiesTreeView" ));
 	selection = gtk_tree_view_get_selection( listview );
 	rows = gtk_tree_selection_get_selected_rows( selection, &model );
 
 	if( g_list_length( rows ) == 1 ){
 		path = ( GtkTreePath * ) rows->data;
 		gtk_tree_model_get_iter( model, &iter, path );
-		gtk_tree_model_get( model, &iter, CAPABILITY_KEYWORD_COLUMN, &dialog->private->capability, -1 );
+		gtk_tree_model_get( model, &iter, CAPABILITY_KEYWORD_COLUMN, &editor->private->capability, -1 );
 	}
 }
-
-static gboolean
-base_dialog_response( GtkDialog *dialog_box, gint code, BaseWindow *window )
-{
-	static const gchar *thisfn = "nact_add_capability_dialog_on_dialog_response";
-	NactAddCapabilityDialog *dialog;
-
-	g_return_val_if_fail( NACT_IS_ADD_CAPABILITY_DIALOG( window ), FALSE );
-
-	dialog = NACT_ADD_CAPABILITY_DIALOG( window );
-
-	if( !dialog->private->dispose_has_run ){
-		g_debug( "%s: dialog_box=%p, code=%d, window=%p", thisfn, ( void * ) dialog_box, code, ( void * ) window );
-
-		switch( code ){
-			case GTK_RESPONSE_OK:
-				validate_dialog( dialog );
-
-			case GTK_RESPONSE_NONE:
-			case GTK_RESPONSE_DELETE_EVENT:
-			case GTK_RESPONSE_CLOSE:
-			case GTK_RESPONSE_CANCEL:
-				return( TRUE );
-				break;
-		}
-	}
-
-	return( FALSE );
-}
