@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -32,17 +31,14 @@
 #include <config.h>
 #endif
 
-#include <gconf/gconf-client.h>
 #include <glib/gi18n.h>
 
 #include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
-#include <core/na-iprefs.h>
-
 #include "base-keysyms.h"
 #include "nact-application.h"
-#include "nact-gtk-utils.h"
+#include "base-gtk-utils.h"
 #include "nact-main-tab.h"
 #include "nact-schemes-list.h"
 
@@ -53,9 +49,16 @@
  * at this time, window is set
  */
 typedef struct {
-	GtkTreeView        *treeview;		/* set when allocating the data */
-	guint               mode;			/* set when creating the model */
-	BaseWindow         *window;			/* set when initializating the view */
+	/* set when creating the model (on_initialize_gtk_toplevel)
+	 */
+	GtkTreeView        *treeview;
+	guint               mode;
+
+	/* set when initializing the view (on_initialize_base_window)
+	 */
+	BaseWindow         *window;
+	gboolean            preferences_locked;
+	gboolean            editable;
 	pf_new_selection_cb pf_on_sel_changed;
 	void               *user_data;
 }
@@ -110,7 +113,21 @@ static SchemesListData *get_schemes_list_data( GtkTreeView *treeview );
  *  or to add a new scheme from the default list.
  *
  * Create the treeview model when initially loading the widget from
- * the UI manager. Associates the SchemesListData structure to the widget.
+ * the UI manager.
+ * Associates the SchemesListData structure to the widget.
+ *
+ * The default list of schemes is displayed in two cases:
+ * - when adding a scheme to a NAObjectItem (cf. NactISchemesTab)
+ *   so the schemes list is opened for selection
+ *
+ *   we have chosen to not allow default schemes list edition in this mode
+ *   because we do not have ok/cancel buttons; the user may start with editing
+ *   and does not have any way of cancel it
+ *
+ * - when editing the default schemes list in Preferences
+ *   so each row may be edited
+ *   edition is only allowed if preferences are not locked and default schemes
+ *   list is not a mandatory pref.
  */
 void
 nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
@@ -132,9 +149,10 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 	gtk_tree_view_set_model( treeview, GTK_TREE_MODEL( model ));
 	g_object_unref( model );
 
+	/* scheme */
 	text_cell = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes(
-			"scheme-code",
+			_( "Keyword" ),
 			text_cell,
 			"text", SCHEMES_KEYWORD_COLUMN,
 			NULL );
@@ -142,20 +160,19 @@ nact_schemes_list_create_model( GtkTreeView *treeview, guint mode )
 	gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE( model ), SCHEMES_KEYWORD_COLUMN, GTK_SORT_ASCENDING );
 	gtk_tree_view_column_set_cell_data_func(
 			column, text_cell, ( GtkTreeCellDataFunc ) display_keyword, data, NULL );
-	nact_gtk_utils_set_editable( G_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
 
+	/* description */
 	text_cell = gtk_cell_renderer_text_new();
 	column = gtk_tree_view_column_new_with_attributes(
-			"scheme-description",
+			_( "Description" ),
 			text_cell,
 			"text", SCHEMES_DESC_COLUMN,
 			NULL );
 	gtk_tree_view_append_column( treeview, column );
 	gtk_tree_view_column_set_cell_data_func(
 			column, text_cell, ( GtkTreeCellDataFunc ) display_description, data, NULL );
-	nact_gtk_utils_set_editable( G_OBJECT( column ), mode == SCHEMES_LIST_FOR_PREFERENCES );
 
-	gtk_tree_view_set_headers_visible( treeview, FALSE );
+	gtk_tree_view_set_headers_visible( treeview, TRUE );
 
 	selection = gtk_tree_view_get_selection( treeview );
 	gtk_tree_selection_set_mode( selection, GTK_SELECTION_BROWSE );
@@ -183,6 +200,8 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
 {
 	static const gchar *thisfn = "nact_schemes_list_init_view";
 	SchemesListData *data;
+	NactApplication *application;
+	NAUpdater *updater;
 
 	g_debug( "%s: treeview=%p, window=%p",
 			thisfn,
@@ -196,6 +215,10 @@ nact_schemes_list_init_view( GtkTreeView *treeview, BaseWindow *window, pf_new_s
 
 	data = get_schemes_list_data( treeview );
 	data->window = window;
+	application = NACT_APPLICATION( base_window_get_application( window ));
+	updater = nact_application_get_updater( application );
+	data->preferences_locked = na_updater_are_preferences_locked( updater );
+	data->editable = ( data->mode == SCHEMES_LIST_FOR_PREFERENCES && !data->preferences_locked );
 	data->pf_on_sel_changed = pf;
 	data->user_data = user_data;
 
@@ -238,16 +261,15 @@ static GSList *
 init_view_get_default_list( SchemesListData *data )
 {
 	GSList *list = NULL;
-	NactApplication *application;
-	NAUpdater *updater;
-
-	application = NACT_APPLICATION( base_window_get_application( data->window ));
-	updater = nact_application_get_updater( application );
-	list = na_iprefs_read_string_list( NA_IPREFS( updater ), "schemes", NULL );
+	gboolean mandatory;
 
+	list = na_settings_get_string_list( NA_IPREFS_SCHEME_DEFAULT_LIST, NULL, &mandatory );
 	if( !list ){
 		list = init_view_get_default_default_list( data );
 	}
+	na_core_utils_slist_dump( "default_list", list );
+
+	data->editable &= !mandatory;
 
 	return( list );
 }
@@ -284,38 +306,49 @@ init_view_connect_signals( SchemesListData *data )
 			"changed",
 			G_CALLBACK( on_selection_changed ));
 
-	if( data->mode == SCHEMES_LIST_FOR_PREFERENCES ){
-
-		column = gtk_tree_view_get_column( data->treeview, SCHEMES_KEYWORD_COLUMN );
+	column = gtk_tree_view_get_column( data->treeview, SCHEMES_KEYWORD_COLUMN );
+	base_gtk_utils_set_editable( G_OBJECT( column ), data->editable );
+	if( data->editable ){
 		renderers = gtk_cell_layout_get_cells( GTK_CELL_LAYOUT( column ));
 		base_window_signal_connect(
 				data->window,
 				G_OBJECT( renderers->data ),
 				"edited",
 				G_CALLBACK( on_keyword_edited ));
+	}
 
-		column = gtk_tree_view_get_column( data->treeview, SCHEMES_DESC_COLUMN );
+	column = gtk_tree_view_get_column( data->treeview, SCHEMES_DESC_COLUMN );
+	base_gtk_utils_set_editable( G_OBJECT( column ), data->editable );
+	if( data->editable ){
 		renderers = gtk_cell_layout_get_cells( GTK_CELL_LAYOUT( column ));
 		base_window_signal_connect(
 				data->window,
 				G_OBJECT( renderers->data ),
 				"edited",
 				G_CALLBACK( on_desc_edited ));
+	}
 
-		add_button = get_add_button( data->window );
+	add_button = get_add_button( data->window );
+	gtk_widget_set_sensitive( GTK_WIDGET( add_button ), data->editable );
+	if( data->editable ){
 		base_window_signal_connect(
 				data->window,
 				G_OBJECT( add_button ),
 				"clicked",
 				G_CALLBACK( on_add_clicked ));
+	}
 
-		remove_button = get_remove_button( data->window );
+	remove_button = get_remove_button( data->window );
+	gtk_widget_set_sensitive( GTK_WIDGET( remove_button ), data->editable );
+	if( data->editable ){
 		base_window_signal_connect(
 				data->window,
 				G_OBJECT( remove_button ),
 				"clicked",
 				G_CALLBACK( on_remove_clicked ));
+	}
 
+	if( data->editable ){
 		base_window_signal_connect(
 				data->window,
 				G_OBJECT( data->treeview ),
@@ -337,7 +370,7 @@ init_view_select_first_row( SchemesListData *data )
 }
 
 /**
- * nact_schemes_list_save_values:
+ * nact_schemes_list_setup_values:
  * @window: the #BaseWindow which embeds this treeview.
  * @schemes: a #GSList of already used schemes.
  *
@@ -394,28 +427,10 @@ nact_schemes_list_show_all( BaseWindow *window )
 	data = get_schemes_list_data( listview );
 
 	button = get_add_button( window );
-#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
 	gtk_widget_set_visible( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
-#else
-	if( data->mode == SCHEMES_LIST_FOR_PREFERENCES ){
-		gtk_widget_show( GTK_WIDGET( button ));
-	} else {
-		gtk_widget_hide( GTK_WIDGET( button ));
-	}
-#endif
-	gtk_widget_set_sensitive( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
 
 	button = get_remove_button( window );
-#if(( GTK_MAJOR_VERSION > 2 ) || ( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 18 ))
 	gtk_widget_set_visible( GTK_WIDGET( button ), data->mode == SCHEMES_LIST_FOR_PREFERENCES );
-#else
-	if( data->mode == SCHEMES_LIST_FOR_PREFERENCES ){
-		gtk_widget_show( GTK_WIDGET( button ));
-	} else {
-		gtk_widget_hide( GTK_WIDGET( button ));
-	}
-#endif
-	gtk_widget_set_sensitive( GTK_WIDGET( button ), FALSE );
 
 	init_view_select_first_row( data );
 }
@@ -466,15 +481,11 @@ nact_schemes_list_save_defaults( BaseWindow *window )
 {
 	GtkTreeView *treeview;
 	GSList *schemes;
-	NactApplication *application;
-	NAUpdater *updater;
 
 	treeview = GTK_TREE_VIEW( g_object_get_data( G_OBJECT( window ), SCHEMES_LIST_TREEVIEW ));
 	schemes = get_list_schemes( treeview );
 
-	application = NACT_APPLICATION( base_window_get_application( window ));
-	updater = nact_application_get_updater( application );
-	na_iprefs_write_string_list( NA_IPREFS( updater ), "schemes", schemes );
+	na_settings_set_string_list( NA_IPREFS_SCHEME_DEFAULT_LIST, schemes );
 
 	na_core_utils_slist_free( schemes );
 }
@@ -573,12 +584,13 @@ on_selection_changed( GtkTreeSelection *selection, BaseWindow *window )
 
 	/*g_debug( "%s: selection=%p, window=%p", thisfn, ( void * ) selection, ( void * ) window );*/
 
-	button = get_remove_button( window );
-	gtk_widget_set_sensitive( GTK_WIDGET( button ), gtk_tree_selection_count_selected_rows( selection ) > 0);
-
 	listview = GTK_TREE_VIEW( g_object_get_data( G_OBJECT( window ), SCHEMES_LIST_TREEVIEW ));
 	data = ( SchemesListData * ) g_object_get_data( G_OBJECT( listview ), SCHEMES_LIST_DATA );
 
+	button = get_remove_button( window );
+	gtk_widget_set_sensitive( GTK_WIDGET( button ),
+			data->editable && gtk_tree_selection_count_selected_rows( selection ) > 0);
+
 	if( data->pf_on_sel_changed ){
 		rows = gtk_tree_selection_get_selected_rows( selection, &model );
 		keyword = NULL;
@@ -751,6 +763,10 @@ display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *m
 	if( used ){
 		g_object_set( cell, "style", PANGO_STYLE_ITALIC, "style-set", TRUE, NULL );
 	}
+
+	if( data->preferences_locked ){
+		g_object_set( cell, "foreground", "Grey", "foreground-set", TRUE, NULL );
+	}
 }
 
 static GtkButton *
