@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -508,16 +508,16 @@ build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection )
 	 */
 	g_object_unref( tokens );
 
-	if( target != ITEM_TARGET_TOOLBAR ){
+	if( target != ITEM_TARGET_TOOLBAR && nautilus_menu && g_list_length( nautilus_menu )){
 
 		items_create_root_menu = na_settings_get_boolean( NA_IPREFS_ITEMS_CREATE_ROOT_MENU, NULL, NULL );
 		if( items_create_root_menu ){
 			nautilus_menu = create_root_menu( plugin, nautilus_menu );
-		}
 
-		items_add_about_item = na_settings_get_boolean( NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, NULL, NULL );
-		if( items_add_about_item ){
-			nautilus_menu = add_about_item( plugin, nautilus_menu );
+			items_add_about_item = na_settings_get_boolean( NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, NULL, NULL );
+			if( items_add_about_item ){
+				nautilus_menu = add_about_item( plugin, nautilus_menu );
+			}
 		}
 	}
 
@@ -557,7 +557,7 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 		 * dynamically empty - thus the NAObjectItem invalid :(
 		 */
 		if( !na_object_is_valid( item )){
-			g_debug( "%s: item %s becomes invalid after expand_tokens_item", thisfn, label );
+			g_debug( "%s: item %s becomes invalid after tokens expansion", thisfn, label );
 			g_object_unref( item );
 			g_free( label );
 			continue;
@@ -567,9 +567,9 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 		 * the 'submenu' menu of nautilusMenuItem's is attached to the returned
 		 * 'item'
 		 */
-		if( NA_IS_OBJECT_MENU( item )){
+		if( NA_IS_OBJECT_MENU( it->data )){
 
-			subitems = na_object_get_items( item );
+			subitems = na_object_get_items( NA_OBJECT( it->data ));
 			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
 
 			submenu = build_nautilus_menu_rec( subitems, target, selection, tokens );
