@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -225,11 +224,9 @@ static void
 first_instance_dispose( GObject *instance )
 {
 	static const gchar *thisfn = "first_instance_dispose";
-	PwiFirst *self;
 
 	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_assert( PWI_IS_FIRST( instance ));
-	self = PWI_FIRST( instance );
 
 	/* chain up to the parent class */
 	G_OBJECT_CLASS( st_first_parent_class )->dispose( instance );
@@ -388,11 +385,9 @@ static void
 first_second_instance_dispose( GObject *instance )
 {
 	static const gchar *thisfn = "first_second_instance_dispose";
-	PwiFirstSecond *self;
 
 	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_assert( PWI_IS_FIRST_SECOND( instance ));
-	self = PWI_FIRST_SECOND( instance );
 
 	/* chain up to the parent class */
 	G_OBJECT_CLASS( st_first_second_parent_class )->dispose( instance );
@@ -520,11 +515,9 @@ static void
 first_second_three_instance_dispose( GObject *instance )
 {
 	static const gchar *thisfn = "first_second_three_instance_dispose";
-	PwiFirstSecondThree *self;
 
 	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 	g_assert( PWI_IS_FIRST_SECOND_THREE( instance ));
-	self = PWI_FIRST_SECOND_THREE( instance );
 
 	/* chain up to the parent class */
 	G_OBJECT_CLASS( st_first_second_three_parent_class )->dispose( instance );
@@ -567,7 +560,9 @@ main( int argc, char **argv )
 	PwiFirstSecond *b;
 	PwiFirstSecondThree *c;
 
+#if !GLIB_CHECK_VERSION( 2,36, 0 )
 	g_type_init();
+#endif
 
 	a = g_object_new( PWI_FIRST_TYPE, NULL );
 	b = g_object_new( PWI_FIRST_SECOND_TYPE, NULL );
