@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2013 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -445,7 +445,9 @@ main( int argc, char **argv )
 	PwiSecond *b;
 	PwiThree *c;
 
+#if !GLIB_CHECK_VERSION( 2,36, 0 )
 	g_type_init();
+#endif
 
 	a = g_object_new( PWI_TYPE_FIRST, NULL );
 	b = g_object_new( PWI_TYPE_SECOND, NULL );
